@@ -1,13 +1,11 @@
-# -*- coding: utf-8 -*-
-
-__version__ = '0.14.9'
+__version__ = '0.14.12'
 
 PROJECT_NAME = "pulsar"
 PROJECT_OWNER = PROJECT_USERAME = "galaxyproject"
 PROJECT_AUTHOR = 'Galaxy Project and Community'
 PROJECT_EMAIL = 'jmchilton@gmail.com'
 
-PROJECT_URL = "https://github.com/%s/%s" % (PROJECT_OWNER, PROJECT_NAME)
-RAW_CONTENT_URL = "https://raw.github.com/%s/%s/master/" % (
+PROJECT_URL = "https://github.com/{}/{}".format(PROJECT_OWNER, PROJECT_NAME)
+RAW_CONTENT_URL = "https://raw.github.com/{}/{}/master/".format(
     PROJECT_USERAME, PROJECT_NAME
 )
